# Codex Build Target

> Placeholder — Codex agent format is under research (IDEA-005).

This directory will contain OpenAI Codex-compatible agent configuration files
once the format is finalized.

See: https://github.com/ievo-ai/cortex/issues (IDEA-005)
